Eco-Connect @ Ecorithm
======================

.. image:: https://travis-ci.org/ecorithm/eco-connect.svg?branch=master
   :target: https://travis-ci.org/ecorithm/eco-connect

.. image:: https://coveralls.io/repos/github/ecorithm/eco-connect/badge.svg?branch=master&t=RDCkPJ
   :target: https://coveralls.io/github/ecorithm/eco-connect?branch=master

A wrapper for connecting to Ecorithm’s API Platform through Python


Documentation
-------------

Available at https://eco-connect.readthedocs.io/en/latest/index.html
